%% This script plots the Figures 10, 11 and 12 of the Fluids journal submission,
%     special issue ComplexFluidsAndFlows_AlgorithmsAndApplications

% Tommy Rigall, 01/04/2021

clear all;
close all;

addpath matlab-master/colormaps % For curves colors Created by Ed Hawkins (@ed_hawkins) and Kevin Anchukaitis

Colors = viridis(100); % For easy translation towards gray scales 
FSize = 14; % Graphical parameter

load('data_Figs10to12','ky','kAccurate','ky_CBC','Eyy_CBC',...
    'Eyy_SG_RFM_x90Lambdaf','Eyy_SG_RFM3D_x90Lambdaf','Eyy_SG_RFM2D_x90Lambdaf',...
    'Eyy_SG_RFM_real2_x90Lambdaf','Eyy_SG_RFM3D_real2_x90Lambdaf','Eyy_SG_RFM2D_real2_x90Lambdaf',...
    'Eyy_MG_RFM_x90Lambdaf','Eyy_MG_RFM3D_x90Lambdaf','Eyy_MG_RFM2D_x90Lambdaf',...
    'Eyy_SG_RFM_x0','Eyy_SG_RFM3D_x0','Eyy_SG_RFM2D_x0',...
    'Eyy_SG_RFM_real2_x0','Eyy_SG_RFM3D_real2_x0','Eyy_SG_RFM2D_real2_x0',...
    'Eyy_MG_RFM_x0','Eyy_MG_RFM3D_x0','Eyy_MG_RFM2D_x0')

% ky                   : wavenumber along the y direction
% kAccurate       : accurate limit of resolution of the 4 th -order 11-point scheme
% CBC                : Comte-Bellot and Corrsin's experiments 
% Eyy                 : One dimensional spectra of the y-velocity along the y
%                           direction
% SG                  : Single Grid configuration
% MG                 : Multi Grids configuration
% RFM               : standard Random Fourier Modes method
% RFM3D          : modified 3D RFM-P method
% RFM2D          : modified 2D RFM-P method
% real2              : Second realization
% Lambda_f      : longitudinal integral length scale
% x90Lambdaf  : Position at 90 Lambdaf from the inlet
% x0                  : Position at the inlet



%% Plotting one dimensional spectra along the y direction Eyy
% Plotting draw 1 
% First Plane - Eyy spectra - x = 0Lambdaf
% Figure 10 a) on the manuscript
figure(100);
loglog(ky,Eyy_SG_RFM_x0,'-','Color',Colors(1,:),'LineWidth',1.5)
hold on
loglog(ky,Eyy_SG_RFM3D_x0,'-','Color',Colors(25,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM2D_x0,'-','Color',Colors(100,:),'LineWidth',1.5)
loglog(ky_CBC,Eyy_CBC,'-ok','Linewidth',1)
xlab = xlabel('k_y (m^{-1})');
ylab = ylabel('E_{vv} (m^3.s^{-2})');
set(gca,'FontSize',FSize)
grid on
h = loglog(ky,(2*ky).^(-5/3),'--g');
plot([kAccurate kAccurate],[1e-10 1e-3],'-.r')
set(h,'LineWidth',1.5);
ylim([1e-8 1e-3])
xlim([10 6e2]);
leg = legend('Single Grid - RFM','Single Grid - RFM-P3D','Single Grid - RFM-P2D',...
             'CBC, JFM 1971'...
             ,'-5/3 Slope','Accurate Limit Resolution');
set([xlab, ylab, leg],'FontName','Arial')
set(leg, 'Position', [0.29, 0.25, .25, .25])

% Plotting draw 1 
% First Plane - Eyy spectra - x = 0Lambdaf
% Figure 10 b) on the manuscript 

figure(101);
loglog(ky,Eyy_MG_RFM_x0,'-','Color',Colors(1,:),'LineWidth',1.5)
hold on
loglog(ky,Eyy_MG_RFM3D_x0,'-','Color',Colors(25,:),'LineWidth',1.5)
loglog(ky,Eyy_MG_RFM2D_x0,'-','Color',Colors(100,:),'LineWidth',1.5)
loglog(ky_CBC,Eyy_CBC,'-ok','Linewidth',1)
xlab = xlabel('k_y (m^{-1})');
ylab = ylabel('E_{vv} (m^3.s^{-2})');
set(gca,'FontSize',FSize)
grid on
h = loglog(ky,(2*ky).^(-5/3),'--g');
plot([kAccurate kAccurate],[1e-10 1e-3],'-.r')
set(h,'LineWidth',1.5);
ylim([1e-8 1e-3])
xlim([10 6e2]);
leg = legend('Single Grid - RFM','Single Grid - RFM-P3D','Single Grid - RFM-P2D',...
             'CBC, JFM 1971'...
             ,'-5/3 Slope','Accurate Limit Resolution');
set([xlab, ylab, leg],'FontName','Arial')
set(leg, 'Position', [0.29, 0.25, .25, .25])

% Plotting draw 1
% Second Plane - Eyy spectra - x = 90Lambdaf
% Figure 10 c) on the manuscript

figure(102);
loglog(ky,Eyy_SG_RFM_x90Lambdaf,'-','Color',Colors(1,:),'LineWidth',1.5)
hold on
loglog(ky,Eyy_SG_RFM3D_x90Lambdaf,'-','Color',Colors(25,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM2D_x90Lambdaf,'-','Color',Colors(100,:),'LineWidth',1.5)
loglog(ky_CBC,Eyy_CBC,'-ok','Linewidth',1)
xlab = xlabel('k_y (m^{-1})');
ylab = ylabel('E_{vv} (m^3.s^{-2})');
set(gca,'FontSize',FSize)
grid on
h = loglog(ky,(2*ky).^(-5/3),'--g');
plot([kAccurate kAccurate],[1e-10 1e-3],'-.r')
set(h,'LineWidth',1.5);
ylim([1e-8 1e-3])
xlim([10 6e2]);
leg = legend('Single Grid - RFM','Single Grid - RFM-P3D','Single Grid - RFM-P2D',...
             'CBC, JFM 1971'...
             ,'-5/3 Slope','Accurate Limit Resolution');
set([xlab, ylab, leg],'FontName','Arial')
set(leg, 'Position', [0.29, 0.25, .25, .25])

% Plotting draw 1
% Second Plane - Eyy spectra - x = 90Lambdaf
% Figure 10 d) on the manuscript

figure(103);
loglog(ky,Eyy_MG_RFM_x90Lambdaf,'-','Color',Colors(1,:),'LineWidth',1.5)
hold on
loglog(ky,Eyy_MG_RFM3D_x90Lambdaf,'-','Color',Colors(25,:),'LineWidth',1.5)
loglog(ky,Eyy_MG_RFM2D_x90Lambdaf,'-','Color',Colors(100,:),'LineWidth',1.5)
loglog(ky_CBC,Eyy_CBC,'-ok','Linewidth',1)
xlab = xlabel('k_y (m^{-1})');
ylab = ylabel('E_{vv} (m^3.s^{-2})');
set(gca,'FontSize',FSize)
grid on
h = loglog(ky,(2*ky).^(-5/3),'--g');
plot([kAccurate kAccurate],[1e-10 1e-3],'-.r')
set(h,'LineWidth',1.5);
ylim([1e-8 1e-3])
xlim([10 6e2]);
leg = legend('Single Grid - RFM','Single Grid - RFM-P3D','Single Grid - RFM-P2D',...
             'CBC, JFM 1971'...
             ,'-5/3 Slope','Accurate Limit Resolution');
set([xlab, ylab, leg],'FontName','Arial')
set(leg, 'Position', [0.29, 0.25, .25, .25])

% Plotting draw 1
% Comparison RFM-P2D and RFM-P3D at both planes (x = 0 and x = 90 Lambdaf)

figure(11);
loglog(ky,Eyy_SG_RFM3D_x0,'-','Color',Colors(1,:),'LineWidth',1.5)
hold on
loglog(ky,Eyy_SG_RFM3D_x90Lambdaf,'--','Color',Colors(1,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM2D_x0,'-','Color',Colors(25,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM2D_x90Lambdaf,'--','Color',Colors(25,:),'LineWidth',1.5)
xlab = xlabel('k_y (m^{-1})');
ylab = ylabel('E_{vv} (m^3.s^{-2})');
set(gca,'FontSize',FSize)
grid on
plot([kAccurate kAccurate],[1e-10 1e-3],'-.r')
set(h,'LineWidth',1.5);
ylim([1e-8 1e-3])
xlim([10 6e2]);
leg = legend('RFM-P3D - x = 0','RFM-P3D - x = 90\Lambda_f','RFM-P2D - x = 0','RFM-P2D - x = 90\Lambda_f',...
             'Accurate Limit Resolution');
set([xlab, ylab, leg],'FontName','Arial')
set(leg, 'Position', [0.29, 0.25, .25, .25])

% Comparison between draws for the Eyy_y spectra
% First Plane - Eyy spectra - x = 0
% Figure 12 a) on the manuscript
figure(120);
loglog(ky,Eyy_SG_RFM_x0,'-','Color',Colors(1,:),'LineWidth',1.5)
hold on
loglog(ky,Eyy_SG_RFM_real2_x0,'--','Color',Colors(1,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM3D_x0,'-','Color',Colors(25,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM3D_real2_x0,'--','Color',Colors(25,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM2D_x0,'-','Color',Colors(100,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM2D_real2_x0,'--','Color',Colors(100,:),'LineWidth',1.5)
xlab = xlabel('k_y (m^{-1})');
ylab = ylabel('E_{vv} (m^3.s^{-2})');
set(gca,'FontSize',FSize)
grid on
plot([kAccurate kAccurate],[1e-10 1e-3],'-.r')
ylim([1e-8 1e-3])
xlim([10 6e2]);
leg = legend('RFM - Realization 1','RFM - Realization 2','RFM-P3D - Realization 1','RFM-P3D - Realization 2','RFM-P2D - Realization 1','RFM-P2D - Realization 2',...
             'Accurate Limit Resolution');
set([xlab, ylab, leg],'FontName','Arial')
set(leg, 'Position', [0.29, 0.25, .25, .25])


% Comparison between draws for the Eyy_y spectra
% Second Plane - Eyy spectra - x = 90Lambdaf
% Figure 12 b) on the manuscript
figure(121);
loglog(ky,Eyy_SG_RFM_x90Lambdaf,'-','Color',Colors(1,:),'LineWidth',1.5)
hold on
loglog(ky,Eyy_SG_RFM_real2_x90Lambdaf,'--','Color',Colors(1,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM3D_x90Lambdaf,'-','Color',Colors(25,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM3D_real2_x90Lambdaf,'--','Color',Colors(25,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM2D_x90Lambdaf,'-','Color',Colors(100,:),'LineWidth',1.5)
loglog(ky,Eyy_SG_RFM2D_real2_x90Lambdaf,'--','Color',Colors(100,:),'LineWidth',1.5)
xlab = xlabel('k_y (m^{-1})');
ylab = ylabel('E_{vv} (m^3.s^{-2})');
set(gca,'FontSize',FSize)
grid on
plot([kAccurate kAccurate],[1e-10 1e-3],'-.r')
ylim([1e-8 1e-3])
xlim([10 6e2]);
leg = legend('RFM - Realization 1','RFM - Realization 2','RFM-P3D - Realization 1','RFM-P3D - Realization 2','RFM-P2D - Realization 1','RFM-P2D - Realization 2',...
             'Accurate Limit Resolution');
set([xlab, ylab, leg],'FontName','Arial')
set(leg, 'Position', [0.29, 0.25, .25, .25])


