%% This script plots the Figures 8 and 9 of the Fluids journal submission,
%     special issue ComplexFluidsAndFlows_AlgorithmsAndApplications

% Tommy Rigall, 01/04/2021

clear all;
close all;

addpath matlab-master/colormaps % For curves colors Created by Ed Hawkins (@ed_hawkins) and Kevin Anchukaitis

Colors = viridis(100); % For easy translation towards gray scales 
FSize = 14; % Graphical parameter

load('data_Figs8and9','x','Lambda_f','TKE_SG_RFM','TKE_SG_RFM3D','TKE_SG_RFM2D',...
    'TKE_MG_RFM','TKE_MG_RFM3D','TKE_MG_RFM2D',...
    'TKE_SG_RFM_real2','TKE_SG_RFM3D_real2','TKE_SG_RFM2D_real2')

% x               : probe positions
% Lambda_f : longitudinal integral length scale
% TKE          : Turbulent Kinetic Energy
% SG            : Single Grid configuration
% MG           : Multi Grids configuration
% RFM         : standard Random Fourier Modes method
% RFM3D    : modified 3D RFM-P method
% RFM2D    : modified 2D RFM-P method
% real2        : Second realization



%% Plotting Turbulent Kinetic Energy (TKE)
% Evolution of the Turbulent Kinetic Energy (TKE) with respect to the
% probes positions (x)
figure(8);
loglog((x+50*Lambda_f)/Lambda_f,TKE_SG_RFM,'-','Color',Colors(1,:),'LineWidth',1.5)
hold on
loglog((x+50*Lambda_f)/Lambda_f,TKE_SG_RFM3D,'-','Color',Colors(25,:),'LineWidth',1.5)
loglog((x+50*Lambda_f)/Lambda_f,TKE_SG_RFM2D,'-','Color',Colors(100,:),'LineWidth',1.5)
loglog((x+50*Lambda_f)/Lambda_f,TKE_MG_RFM,'--','Color',Colors(1,:),'LineWidth',1.5)
loglog((x+50*Lambda_f)/Lambda_f,TKE_MG_RFM3D,'--','Color',Colors(25,:),'LineWidth',1.5)
loglog((x+50*Lambda_f)/Lambda_f,TKE_MG_RFM2D,'--','Color',Colors(100,:),'LineWidth',1.5)
xlim([0 95])
ylim([0.02 0.08])
set(gca,'Fontsize',FSize)
grid on
xlab = xlabel('x/\Lambda_f');
ylab = ylabel('k_t^r (m^2.s^{-2})');
n_1 = 0.95;
n_2 = 1.43;
loglog((x+50*Lambda_f)/Lambda_f,3*((x+50*Lambda_f)/Lambda_f).^(-n_1),'-.','Color',Colors(15,:),'LineWidth',1.5)
loglog((x+50*Lambda_f)/Lambda_f,15*((x+50*Lambda_f)/Lambda_f).^(-n_2),':','Color',Colors(15,:),'LineWidth',1.5)
leg = legend('Single Grid - RFM','Single Grid - RFM-P3D','Single Grid - RFM-P2D','Multi Grids - RFM','Multi Grids - RFM-P3D','Multi Grids - RFM-P2D','-0.95 Exponent', '-1.43 Exponent');
set([xlab, ylab, leg],'FontName','Arial')
set(leg, 'Position', [0.25, 0.3, .25, .25])

% Comparison between draws for the TKE
figure(9);
loglog((x+50*Lambda_f)/Lambda_f,TKE_SG_RFM,'-','Color',Colors(1,:),'LineWidth',1.5)
hold on
loglog((x+50*Lambda_f)/Lambda_f,TKE_SG_RFM_real2,'--','Color',Colors(1,:),'LineWidth',1.5)
loglog((x+50*Lambda_f)/Lambda_f,TKE_SG_RFM3D,'-','Color',Colors(25,:),'LineWidth',1.5)
loglog((x+50*Lambda_f)/Lambda_f,TKE_SG_RFM3D_real2,'--','Color',Colors(25,:),'LineWidth',1.5)
loglog((x+50*Lambda_f)/Lambda_f,TKE_SG_RFM2D,'-','Color',Colors(100,:),'LineWidth',1.5)
loglog((x+50*Lambda_f)/Lambda_f,TKE_SG_RFM2D_real2,'--','Color',Colors(100,:),'LineWidth',1.5)
xlim([0 95])
ylim([0.02 0.09])
set(gca,'Fontsize',FSize)
grid on
xlab = xlabel('x/\Lambda_f');
ylab = ylabel('k_t^r (m^2.s^{-2})');
leg = legend('RFM - Realization 1','RFM - Realization 2','RFM-P3D - Realization 1','RFM-P3D - Realization 2','RFM-P2D - Realization 1','RFM-P2D - Realization 2');
set([xlab, ylab, leg],'FontName','Arial')
set(leg, 'Position', [0.25, 0.3, .25, .25])